| Title: | Spatial Analysis in Archaeology from Refitting Fragments (GUI) |
|---|---|
| Description: | A 'Shiny' application to access the functionalities and datasets of the 'archeofrag' package for spatial analysis in archaeology from refitting data. Quick and seamless exploration of archaeological refitting datasets, focusing on physical refits only. Features include: built-in documentation and convenient workflow, plot generation and exports, anomaly detection in the spatial distribution of refitting connection, exploration of spatial units merging solutions, simulation of archaeological site formation processes, support for parallel computing, R code generation to re-execute simulations and ensure reproducibility, code generation for the 'openMOLE' model exploration software. A demonstration of the app is available at <https://analytics.huma-num.fr/Sebastien.Plutniak/archeofrag/>. |
| Authors: | Sebastien Plutniak [aut, cre]
|
| Maintainer: | Sebastien Plutniak <[email protected]> |
| License: | GPL-3 |
| Version: | 1.1.5 |
| Built: | 2026-06-07 06:24:04 UTC |
| Source: | https://github.com/sebastien-plutniak/archeofrag.gui |
Launch the archeofrag.gui application
archeofrag.gui(n.cores=NULL)archeofrag.gui(n.cores=NULL)
n.cores |
integer. The number of cores to use for parallel execution. If NULL, half of the available cores are registered. |
This function launches the 'archeofrag.gui' application.
Note that the optional determination of graph planarity in the archeofrag package requires the RBGL package.
Launch the 'archeofrag.gui' R Shiny application.
Sebastien Plutniak <sebastien.plutniak at posteo.net>
archeofrag
frag.simul.process
frag.get.parameters
registerDoParallel
# launching the app: if(interactive()){ archeofrag.gui() }# launching the app: if(interactive()){ archeofrag.gui() }