Welcome to ClientVPS Mirrors

Help for package archeofrag.gui
Type: Package
Title: Spatial Analysis in Archaeology from Refitting Fragments (GUI)
Version: 1.1.4
Date: 2026-01-06
Author: Sebastien Plutniak ORCID iD [aut, cre]
Maintainer: Sebastien Plutniak <sebastien.plutniak@posteo.net>
Description: A 'Shiny' application to access the functionalities and datasets of the 'archeofrag' package for spatial analysis in archaeology from refitting data. Quick and seamless exploration of archaeological refitting datasets, focusing on physical refits only. Features include: built-in documentation and convenient workflow, plot generation and exports, anomaly detection in the spatial distribution of refitting connection, exploration of spatial units merging solutions, simulation of archaeological site formation processes, support for parallel computing, R code generation to re-execute simulations and ensure reproducibility, code generation for the 'openMOLE' model exploration software. A demonstration of the app is available at https://analytics.huma-num.fr/Sebastien.Plutniak/archeofrag/.
License: GPL-3
Repository: CRAN
Encoding: UTF-8
Imports: archeofrag, dendextend, doParallel, doRNG, DT, foreach, ggplot2, grDevices, igraph, shiny, shinythemes,
Suggests: RBGL,
URL: https://github.com/sebastien-plutniak/archeofrag.gui
BugReports: https://github.com/sebastien-plutniak/archeofrag.gui/issues
NeedsCompilation: no
Packaged: 2026-01-06 13:52:23 UTC; seb
Date/Publication: 2026-01-11 13:30:02 UTC

archeofrag.gui

Description

Launch the archeofrag.gui application

Usage

archeofrag.gui(n.cores=NULL)

Arguments

n.cores

integer. The number of cores to use for parallel execution. If NULL, half of the available cores are registered.

Details

This function launches the 'archeofrag.gui' application.

Note that the optional determination of graph planarity in the archeofrag package requires the RBGL package.

Value

Launch the 'archeofrag.gui' R Shiny application.

Author(s)

Sebastien Plutniak <sebastien.plutniak at posteo.net>

See Also

archeofrag frag.simul.process frag.get.parameters registerDoParallel

Examples

    # launching the app:
    if(interactive()){
     archeofrag.gui()
    }

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.